@@ -65,9 +65,9 @@ mount( const std::string& device_path,
        const std::string& options )
 {
     return CalamaresUtils::Partition::mount( QString::fromStdString( device_path ),
-                  QString::fromStdString( mount_point ),
-                  QString::fromStdString( filesystem_name ),
-                  QString::fromStdString( options ) );
+                                             QString::fromStdString( mount_point ),
+                                             QString::fromStdString( filesystem_name ),
+                                             QString::fromStdString( options ) );
 }
 
 
@@ -171,7 +171,7 @@ PythonJobInterface::PythonJobInterface( Calamares::PythonJob* parent )
 void
 PythonJobInterface::setprogress( qreal progress )
 {
-    if ( progress >= 0 && progress <= 1 )
+    if ( progress >= 0.0 && progress <= 1.0 )
     {
         m_parent->emitProgress( progress );
     }
