@@ -40,10 +40,6 @@ class Label : public QObject
 {
     Q_OBJECT
 
-    Q_PROPERTY( QString label READ label CONSTANT FINAL )
-    Q_PROPERTY( QString englishLabel READ englishLabel CONSTANT FINAL )
-    Q_PROPERTY( QString localeId MEMBER m_localeId CONSTANT FINAL )
-
 public:
     /** @brief Formatting option for label -- add (country) to label. */
     enum class LabelFormat
@@ -65,6 +61,7 @@ public:
            LabelFormat format = LabelFormat::IfNeededWithCountry,
            QObject* parent = nullptr );
 
+
     /** @brief Define a sorting order.
      *
      * Locales are sorted by their id, which means the ISO 2-letter code + country.
