@@ -28,6 +28,8 @@
 
 #include <QMap>
 #include <QObject>
+#include <QPixmap>
+#include <QSize>
 #include <QStringList>
 
 namespace YAML
@@ -61,16 +63,18 @@ public:
         ProductUrl,
         SupportUrl,
         KnownIssuesUrl,
-        ReleaseNotesUrl
+        ReleaseNotesUrl,
+        DonateUrl
     };
     Q_ENUM( StringEntry )
 
     enum ImageEntry : short
     {
-        ProductLogo,
+        ProductBanner,
         ProductIcon,
-        ProductWelcome,
-        ProductWallpaper
+        ProductLogo,
+        ProductWallpaper,
+        ProductWelcome
     };
     Q_ENUM( ImageEntry )
 
@@ -122,6 +126,25 @@ public:
         Center,
         Free
     };
+    Q_ENUM( WindowPlacement )
+    ///@brief What kind of panel (sidebar, navigation) to use in the main window
+    enum class PanelFlavor
+    {
+        None,
+        Widget,
+        Qml
+    };
+    Q_ENUM( PanelFlavor )
+    ///@brief Where to place a panel (sidebar, navigation)
+    enum class PanelSide
+    {
+        None,
+        Left,
+        Right,
+        Top,
+        Bottom
+    };
+    Q_ENUM( PanelSide )
 
     static Branding* instance();
 
@@ -175,6 +198,11 @@ public:
     }
     bool windowPlacementCentered() const { return m_windowPlacement == WindowPlacement::Center; }
 
+    ///@brief Which sidebar flavor is configured
+    PanelFlavor sidebarFlavor() const { return m_sidebarFlavor; }
+    ///@brief Which navigation flavor is configured
+    PanelFlavor navigationFlavor() const { return m_navigationFlavor; }
+
     /**
      * Creates a map called "branding" in the global storage, and inserts an
      * entry for each of the branding strings. This makes the branding
@@ -184,9 +212,17 @@ public:
 
 public slots:
     QString string( StringEntry stringEntry ) const;
+    QString versionedName() const { return string( VersionedName ); }
+    QString productName() const { return string( ProductName ); }
+    QString shortProductName() const { return string( ShortProductName ); }
+    QString shortVersionedName() const { return string( ShortVersionedName ); }
+
     QString styleString( StyleEntry styleEntry ) const;
     QString imagePath( ImageEntry imageEntry ) const;
 
+    PanelSide sidebarSide() const { return m_sidebarSide; }
+    PanelSide navigationSide() const { return m_navigationSide; }
+
 private:
     static Branding* s_instance;
 
@@ -214,13 +250,12 @@ private:
     WindowExpansion m_windowExpansion;
     WindowDimension m_windowHeight, m_windowWidth;
     WindowPlacement m_windowPlacement;
-};
 
-template < typename U >
-inline QString operator*( U e )
-{
-    return Branding::instance()->string( e );
-}
+    PanelFlavor m_sidebarFlavor = PanelFlavor::Widget;
+    PanelFlavor m_navigationFlavor = PanelFlavor::Widget;
+    PanelSide m_sidebarSide = PanelSide::Left;
+    PanelSide m_navigationSide = PanelSide::Bottom;
+};
 
 }  // namespace Calamares
 
