@@ -3,7 +3,7 @@
  *   Copyright 2019, Dominic Hayes <ferenosdev@outlook.com>
  *   Copyright 2019, Gabriel Craciunescu <crazy@frugalware.org>
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 #include "utils/Paste.h"
 #include "utils/Retranslator.h"
 #include "viewpages/BlankViewStep.h"
-#include "viewpages/ViewStep.h"
 #include "viewpages/ExecutionViewStep.h"
+#include "viewpages/ViewStep.h"
 
 #include <QApplication>
 #include <QBoxLayout>
@@ -38,6 +38,12 @@
 #include <QMessageBox>
 #include <QMetaObject>
 
+#define UPDATE_BUTTON_PROPERTY( name, value ) \
+    { \
+        m_##name = value; \
+        emit name##Changed( m_##name ); \
+    }
+
 namespace Calamares
 {
 
@@ -57,74 +63,28 @@ ViewManager::instance( QObject* parent )
     return s_instance;
 }
 
-/** @brief Get a button-sized icon. */
-static inline QPixmap
-getButtonIcon( const QString& name )
-{
-    return Calamares::Branding::instance()->image( name, QSize( 22, 22 ) );
-}
-
-static inline void
-setButtonIcon( QPushButton* button, const QString& name )
-{
-    auto icon = getButtonIcon( name );
-    if ( button && !icon.isNull() )
-    {
-        button->setIcon( icon );
-    }
-}
-
 ViewManager::ViewManager( QObject* parent )
-    : QObject( parent )
-    , m_currentStep( 0 )
+    : QAbstractListModel( parent )
+    , m_currentStep( -1 )
     , m_widget( new QWidget() )
 {
     Q_ASSERT( !s_instance );
 
     QBoxLayout* mainLayout = new QVBoxLayout;
+    m_widget->setObjectName( "viewManager" );
     m_widget->setLayout( mainLayout );
 
     m_stack = new QStackedWidget( m_widget );
+    m_stack->setObjectName( "viewManagerStack" );
     m_stack->setContentsMargins( 0, 0, 0, 0 );
     mainLayout->addWidget( m_stack );
 
-    // Create buttons and sets an initial icon; the icons may change
-    m_back = new QPushButton( getButtonIcon( QStringLiteral( "go-previous" ) ), tr( "&Back" ), m_widget );
-    m_back->setObjectName( "view-button-back" );
-    m_next = new QPushButton( getButtonIcon( QStringLiteral( "go-next" ) ), tr( "&Next" ), m_widget );
-    m_next->setObjectName( "view-button-next" );
-    m_quit = new QPushButton( getButtonIcon( QStringLiteral( "dialog-cancel" ) ), tr( "&Cancel" ), m_widget );
-    m_quit->setObjectName( "view-button-cancel" );
+    updateButtonLabels();
 
-    CALAMARES_RETRANSLATE_SLOT( &ViewManager::updateButtonLabels )
-
-    QBoxLayout* bottomLayout = new QHBoxLayout;
-    mainLayout->addLayout( bottomLayout );
-    bottomLayout->addStretch();
-    bottomLayout->addWidget( m_back );
-    bottomLayout->addWidget( m_next );
-    bottomLayout->addSpacing( 12 );
-    bottomLayout->addWidget( m_quit );
-
-    connect( m_next, &QPushButton::clicked, this, &ViewManager::next );
-    connect( m_back, &QPushButton::clicked, this, &ViewManager::back );
-    m_back->setEnabled( false );
-
-    connect( m_quit, &QPushButton::clicked, this, [this]() {
-        if ( this->confirmCancelInstallation() )
-        {
-            qApp->quit();
-        }
-    } );
     connect( JobQueue::instance(), &JobQueue::failed, this, &ViewManager::onInstallationFailed );
     connect( JobQueue::instance(), &JobQueue::finished, this, &ViewManager::next );
 
-    if ( Calamares::Settings::instance()->disableCancel() )
-    {
-        m_quit->setVisible( false );
-    }
-
-    // onInstallationFailed( "Title of Failure", "Body of Failure");  // for testing paste functionality
+    CALAMARES_RETRANSLATE_SLOT( &ViewManager::updateButtonLabels )
 }
 
 
@@ -149,7 +109,8 @@ ViewManager::addViewStep( ViewStep* step )
     // If this is the first inserted view step, update status of "Next" button
     if ( m_steps.count() == 1 )
     {
-        m_next->setEnabled( step->isNextEnabled() );
+        m_nextEnabled = step->isNextEnabled();
+        emit nextEnabledChanged( m_nextEnabled );
     }
 }
 
@@ -157,18 +118,10 @@ ViewManager::addViewStep( ViewStep* step )
 void
 ViewManager::insertViewStep( int before, ViewStep* step )
 {
+    emit beginInsertRows( QModelIndex(), before, before );
     m_steps.insert( before, step );
-    connect( step, &ViewStep::enlarge, this, &ViewManager::enlarge );
-    connect( step, &ViewStep::nextStatusChanged, this, [this]( bool status ) {
-        ViewStep* vs = qobject_cast< ViewStep* >( sender() );
-        if ( vs )
-        {
-            if ( vs == m_steps.at( m_currentStep ) )
-            {
-                m_next->setEnabled( status );
-            }
-        }
-    } );
+    connect( step, &ViewStep::ensureSize, this, &ViewManager::ensureSize );
+    connect( step, &ViewStep::nextStatusChanged, this, &ViewManager::updateNextStatus );
 
     if ( !step->widget() )
     {
@@ -183,6 +136,7 @@ ViewManager::insertViewStep( int before, ViewStep* step )
     m_stack->insertWidget( before, step->widget() );
     m_stack->setCurrentIndex( 0 );
     step->widget()->setFocus();
+    emit endInsertRows();
 }
 
 
@@ -229,7 +183,7 @@ ViewManager::onInstallationFailed( const QString& message, const QString& detail
     msgBox->show();
 
     cDebug() << "Calamares will quit when the dialog closes.";
-    connect( msgBox, &QMessageBox::buttonClicked, [msgBox]( QAbstractButton* button ) {
+    connect( msgBox, &QMessageBox::buttonClicked, [ msgBox ]( QAbstractButton* button ) {
         if ( msgBox->buttonRole( button ) == QMessageBox::ButtonRole::YesRole )
         {
             // TODO: host and port should be configurable
@@ -272,9 +226,38 @@ ViewManager::onInitFailed( const QStringList& modules )
         detailString = details.join( QString() );
     }
 
-    insertViewStep( 0, new BlankViewStep( title, description.arg( *Calamares::Branding::ProductName ), detailString ) );
+    insertViewStep(
+        0,
+        new BlankViewStep( title, description.arg( Calamares::Branding::instance()->productName() ), detailString ) );
 }
 
+void
+ViewManager::onInitComplete()
+{
+    m_currentStep = 0;
+
+    // Tell the first view that it's been shown.
+    if ( m_steps.count() > 0 )
+    {
+        m_steps.first()->onActivate();
+    }
+}
+
+void
+ViewManager::updateNextStatus( bool status )
+{
+    ViewStep* vs = qobject_cast< ViewStep* >( sender() );
+    if ( vs && currentStepValid() )
+    {
+        if ( vs == m_steps.at( m_currentStep ) )
+        {
+            m_nextEnabled = status;
+            emit nextEnabledChanged( m_nextEnabled );
+        }
+    }
+}
+
+
 ViewStepList
 ViewManager::viewSteps() const
 {
@@ -285,7 +268,7 @@ ViewManager::viewSteps() const
 ViewStep*
 ViewManager::currentStep() const
 {
-    return m_steps.value( m_currentStep );
+    return currentStepValid() ? m_steps.value( m_currentStep ) : nullptr;
 }
 
 
@@ -307,9 +290,31 @@ stepIsExecute( const ViewStepList& steps, int index )
         && ( qobject_cast< ExecutionViewStep* >( steps.at( index ) ) != nullptr );
 }
 
+static inline bool
+isAtVeryEnd( const ViewStepList& steps, int index )
+{
+    // If we have an empty list, then there's no point right now
+    // in checking if we're at the end.
+    if ( steps.count() == 0 )
+    {
+        return false;
+    }
+    // .. and if the index is invalid, ignore it too
+    if ( !( ( 0 <= index ) && ( index < steps.count() ) ) )
+    {
+        return false;
+    }
+    return ( index >= steps.count() ) || ( index == steps.count() - 1 && steps.last()->isAtEnd() );
+}
+
 void
 ViewManager::next()
 {
+    if ( !currentStepValid() )
+    {
+        return;
+    }
+
     ViewStep* step = m_steps.at( m_currentStep );
     bool executing = false;
     if ( step->isAtEnd() )
@@ -332,15 +337,16 @@ ViewManager::next()
                       "to undo these changes.</strong>" );
             QString confirm = settings->isSetupMode() ? tr( "&Set up now" ) : tr( "&Install now" );
 
-            int reply = QMessageBox::question(
-                m_widget,
-                title,
-                question.arg( *Calamares::Branding::ShortProductName, *Calamares::Branding::ShortVersionedName ),
-                confirm,
-                tr( "Go &back" ),
-                QString(),
-                0 /* default first button, i.e. confirm */,
-                1 /* escape is second button, i.e. cancel */ );
+            const auto* branding = Calamares::Branding::instance();
+            int reply
+                = QMessageBox::question( m_widget,
+                                         title,
+                                         question.arg( branding->shortProductName(), branding->shortVersionedName() ),
+                                         confirm,
+                                         tr( "Go &back" ),
+                                         QString(),
+                                         0 /* default first button, i.e. confirm */,
+                                         1 /* escape is second button, i.e. cancel */ );
             if ( reply == 1 )
             {
                 return;
@@ -362,8 +368,8 @@ ViewManager::next()
         {
             // Reached the end in a weird state (e.g. no finished step after an exec)
             executing = false;
-            m_next->setEnabled( false );
-            m_back->setEnabled( false );
+            UPDATE_BUTTON_PROPERTY( nextEnabled, false )
+            UPDATE_BUTTON_PROPERTY( backEnabled, false )
         }
         updateCancelEnabled( !settings->disableCancel() && !( executing && settings->disableCancelDuringExec() ) );
     }
@@ -374,8 +380,8 @@ ViewManager::next()
 
     if ( m_currentStep < m_steps.count() )
     {
-        m_next->setEnabled( !executing && m_steps.at( m_currentStep )->isNextEnabled() );
-        m_back->setEnabled( !executing && m_steps.at( m_currentStep )->isBackEnabled() );
+        UPDATE_BUTTON_PROPERTY( nextEnabled, !executing && m_steps.at( m_currentStep )->isNextEnabled() )
+        UPDATE_BUTTON_PROPERTY( backEnabled, !executing && m_steps.at( m_currentStep )->isBackEnabled() )
     }
 
     updateButtonLabels();
@@ -397,45 +403,55 @@ ViewManager::updateButtonLabels()
     // If we're going into the execution step / install phase, other message
     if ( stepIsExecute( m_steps, m_currentStep + 1 ) )
     {
-        m_next->setText( nextIsInstallationStep );
-        setButtonIcon( m_next, "run-install" );
+        UPDATE_BUTTON_PROPERTY( nextLabel, nextIsInstallationStep )
+        UPDATE_BUTTON_PROPERTY( nextIcon, "run-install" )
     }
     else
     {
-        m_next->setText( tr( "&Next" ) );
-        setButtonIcon( m_next, "go-next" );
+        UPDATE_BUTTON_PROPERTY( nextLabel, tr( "&Next" ) )
+        UPDATE_BUTTON_PROPERTY( nextIcon, "go-next" )
     }
 
     // Going back is always simple
-    m_back->setText( tr( "&Back" ) );
+    UPDATE_BUTTON_PROPERTY( backLabel, tr( "&Back" ) )
+    UPDATE_BUTTON_PROPERTY( backIcon, "go-previous" )
 
     // Cancel button changes label at the end
-    if ( isAtVeryEnd() )
+    if ( isAtVeryEnd( m_steps, m_currentStep ) )
     {
-        m_quit->setText( tr( "&Done" ) );
-        m_quit->setToolTip( quitOnCompleteTooltip );
-        m_quit->setVisible( true );  // At end, always visible and enabled.
-        setButtonIcon( m_quit, "dialog-ok-apply" );
+        UPDATE_BUTTON_PROPERTY( quitLabel, tr( "&Done" ) )
+        UPDATE_BUTTON_PROPERTY( quitTooltip, quitOnCompleteTooltip )
+        UPDATE_BUTTON_PROPERTY( quitVisible, true )
+        UPDATE_BUTTON_PROPERTY( quitIcon, "dialog-ok-apply" )
         updateCancelEnabled( true );
+        if ( settings->quitAtEnd() )
+        {
+            quit();
+        }
     }
     else
     {
         if ( settings->disableCancel() )
         {
-            m_quit->setVisible( false );  // In case we went back from final
+            UPDATE_BUTTON_PROPERTY( quitVisible, false )
         }
         updateCancelEnabled( !settings->disableCancel()
                              && !( stepIsExecute( m_steps, m_currentStep ) && settings->disableCancelDuringExec() ) );
 
-        m_quit->setText( tr( "&Cancel" ) );
-        m_quit->setToolTip( cancelBeforeInstallationTooltip );
-        setButtonIcon( m_quit, "dialog-cancel" );
+        UPDATE_BUTTON_PROPERTY( quitLabel, tr( "&Cancel" ) )
+        UPDATE_BUTTON_PROPERTY( quitTooltip, cancelBeforeInstallationTooltip )
+        UPDATE_BUTTON_PROPERTY( quitIcon, "dialog-cancel" )
     }
 }
 
 void
 ViewManager::back()
 {
+    if ( !currentStepValid() )
+    {
+        return;
+    }
+
     ViewStep* step = m_steps.at( m_currentStep );
     if ( step->isAtBeginning() && m_currentStep > 0 )
     {
@@ -454,24 +470,32 @@ ViewManager::back()
         return;
     }
 
-    m_next->setEnabled( m_steps.at( m_currentStep )->isNextEnabled() );
-    m_back->setEnabled( m_steps.at( m_currentStep )->isBackEnabled() );
-
-    if ( m_currentStep == 0 && m_steps.first()->isAtBeginning() )
-    {
-        m_back->setEnabled( false );
-    }
+    UPDATE_BUTTON_PROPERTY( nextEnabled, m_steps.at( m_currentStep )->isNextEnabled() )
+    UPDATE_BUTTON_PROPERTY( backEnabled,
+                            ( m_currentStep == 0 && m_steps.first()->isAtBeginning() )
+                                ? false
+                                : m_steps.at( m_currentStep )->isBackEnabled() )
 
     updateButtonLabels();
 }
 
+
+void
+ViewManager::quit()
+{
+    if ( confirmCancelInstallation() )
+    {
+        qApp->quit();
+    }
+}
+
 bool
 ViewManager::confirmCancelInstallation()
 {
     const auto* const settings = Calamares::Settings::instance();
 
     // When we're at the very end, then it's always OK to exit.
-    if ( isAtVeryEnd() )
+    if ( isAtVeryEnd( m_steps, m_currentStep ) )
     {
         return true;
     }
@@ -503,8 +527,65 @@ ViewManager::confirmCancelInstallation()
 void
 ViewManager::updateCancelEnabled( bool enabled )
 {
-    m_quit->setEnabled( enabled );
+    UPDATE_BUTTON_PROPERTY( quitEnabled, enabled )
     emit cancelEnabled( enabled );
 }
 
+QVariant
+ViewManager::data( const QModelIndex& index, int role ) const
+{
+    if ( !index.isValid() )
+    {
+        return QVariant();
+    }
+
+    if ( ( index.row() < 0 ) || ( index.row() >= m_steps.length() ) )
+    {
+        return QVariant();
+    }
+
+    const auto* step = m_steps.at( index.row() );
+    if ( !step )
+    {
+        return QVariant();
+    }
+
+    switch ( role )
+    {
+    case Qt::DisplayRole:
+        return step->prettyName();
+    case Qt::ToolTipRole:
+        if ( Calamares::Settings::instance()->debugMode() )
+        {
+            auto key = step->moduleInstanceKey();
+            QString toolTip( "<b>Debug information</b>" );
+            toolTip.append( "<br/>Type:\tViewStep" );
+            toolTip.append( QString( "<br/>Pretty:\t%1" ).arg( step->prettyName() ) );
+            toolTip.append( QString( "<br/>Status:\t%1" ).arg( step->prettyStatus() ) );
+            toolTip.append(
+                QString( "<br/>Source:\t%1" ).arg( key.isValid() ? key.toString() : QStringLiteral( "built-in" ) ) );
+            return toolTip;
+        }
+        else
+        {
+            return QVariant();
+        }
+    case ProgressTreeItemCurrentIndex:
+        return m_currentStep;
+    default:
+        return QVariant();
+    }
+}
+
+
+int
+ViewManager::rowCount( const QModelIndex& parent ) const
+{
+    if ( parent.column() > 0 )
+    {
+        return 0;
+    }
+    return m_steps.length();
+}
+
 }  // namespace Calamares
