@@ -19,11 +19,12 @@
 
 #include "ModuleManager.h"
 
-#include "Module.h"
-#include "RequirementsChecker.h"
-#include "Settings.h"
 #include "ViewManager.h"
 
+#include "Settings.h"
+#include "modulesystem/Module.h"
+#include "modulesystem/RequirementsChecker.h"
+#include "modulesystem/RequirementsModel.h"
 #include "utils/Logger.h"
 #include "utils/Yaml.h"
 #include "viewpages/ExecutionViewStep.h"
@@ -46,6 +47,7 @@ ModuleManager::instance()
 ModuleManager::ModuleManager( const QStringList& paths, QObject* parent )
     : QObject( parent )
     , m_paths( paths )
+    , m_requirementsModel( new RequirementsModel( this ) )
 {
     Q_ASSERT( !s_instance );
     s_instance = this;
@@ -129,9 +131,8 @@ ModuleManager::doInit()
     }
     // At this point m_availableDescriptorsByModuleName is filled with
     // the modules that were found in the search paths.
-    cDebug() << "Found"
-        << m_availableDescriptorsByModuleName.count() << "modules"
-        << m_moduleDirectoriesByModuleName.count() << "names";
+    cDebug() << "Found" << m_availableDescriptorsByModuleName.count() << "modules"
+             << m_moduleDirectoriesByModuleName.count() << "names";
     emit initDone();
 }
 
@@ -167,7 +168,7 @@ findCustomInstance( const Settings::InstanceDescriptionList& customInstances, co
     for ( int i = 0; i < customInstances.count(); ++i )
     {
         const auto& thisInstance = customInstances[ i ];
-        if ( thisInstance.value( "module" ) == m.module() && thisInstance.value( "id" ) == m.id() )
+        if ( thisInstance.module == m.module() && thisInstance.id == m.id() )
         {
             return i;
         }
@@ -196,7 +197,7 @@ getConfigFileName( const Settings::InstanceDescriptionList& customInstances,
             return QString();
         }
 
-        return customInstances[ found ].value( "config" );
+        return customInstances[ found ].config;
     }
     else
     {
@@ -286,10 +287,11 @@ ModuleManager::loadModules()
             }
             else
             {
-                thisModule = Module::fromDescriptor( descriptor,
-                                                     instanceKey.id(),
-                                                     configFileName,
-                                                     m_moduleDirectoriesByModuleName.value( instanceKey.module() ) );
+                thisModule
+                    = Calamares::moduleFromDescriptor( descriptor,
+                                                       instanceKey.id(),
+                                                       configFileName,
+                                                       m_moduleDirectoriesByModuleName.value( instanceKey.module() ) );
                 if ( !thisModule )
                 {
                     cError() << "Module" << instanceKey.toString() << "cannot be created from descriptor"
@@ -355,11 +357,10 @@ ModuleManager::checkRequirements()
         modules[ count++ ] = module;
     }
 
-    RequirementsChecker* rq = new RequirementsChecker( modules, this );
-    connect( rq, &RequirementsChecker::requirementsResult, this, &ModuleManager::requirementsResult );
-    connect( rq, &RequirementsChecker::requirementsComplete, this, &ModuleManager::requirementsComplete );
+    RequirementsChecker* rq = new RequirementsChecker( modules, m_requirementsModel, this );
     connect( rq, &RequirementsChecker::requirementsProgress, this, &ModuleManager::requirementsProgress );
     connect( rq, &RequirementsChecker::done, rq, &RequirementsChecker::deleteLater );
+    connect( rq, &RequirementsChecker::done, this, [=](){ this->requirementsComplete( m_requirementsModel->satisfiedMandatory() ); } );
 
     QTimer::singleShot( 0, rq, &RequirementsChecker::run );
 }
