@@ -23,16 +23,17 @@
 
 ClickableLabel::ClickableLabel( QWidget* parent )
     : QLabel( parent )
-{}
+{
+}
 
 
 ClickableLabel::ClickableLabel( const QString& text, QWidget* parent )
     : QLabel( text, parent )
-{}
+{
+}
 
 
-ClickableLabel::~ClickableLabel()
-{}
+ClickableLabel::~ClickableLabel() { }
 
 
 void
@@ -48,5 +49,7 @@ ClickableLabel::mouseReleaseEvent( QMouseEvent* event )
 {
     QLabel::mouseReleaseEvent( event );
     if ( m_time.elapsed() < qApp->doubleClickInterval() )
+    {
         emit clicked();
+    }
 }
