@@ -28,7 +28,6 @@ KeyboardLayoutModel::KeyboardLayoutModel( QObject* parent )
     init();
 }
 
-
 int
 KeyboardLayoutModel::rowCount( const QModelIndex& parent ) const
 {
@@ -41,7 +40,9 @@ QVariant
 KeyboardLayoutModel::data( const QModelIndex& index, int role ) const
 {
     if ( !index.isValid() )
+    {
         return QVariant();
+    }
 
     switch ( role )
     {
@@ -56,19 +57,54 @@ KeyboardLayoutModel::data( const QModelIndex& index, int role ) const
     return QVariant();
 }
 
+const QPair< QString, KeyboardGlobal::KeyboardInfo >
+KeyboardLayoutModel::item( const int& index ) const
+{
+    if ( index >= m_layouts.count() || index < 0 )
+    {
+        return QPair< QString, KeyboardGlobal::KeyboardInfo >();
+    }
+
+    return m_layouts.at( index );
+}
 
 void
 KeyboardLayoutModel::init()
 {
-    KeyboardGlobal::LayoutsMap layouts =
-        KeyboardGlobal::getKeyboardLayouts();
-    for ( KeyboardGlobal::LayoutsMap::const_iterator it = layouts.constBegin();
-            it != layouts.constEnd(); ++it )
-        m_layouts.append( qMakePair( it.key(), it.value() ) );
-
-    std::stable_sort( m_layouts.begin(), m_layouts.end(), []( const QPair< QString, KeyboardGlobal::KeyboardInfo >& a,
-                      const QPair< QString, KeyboardGlobal::KeyboardInfo >& b )
+    KeyboardGlobal::LayoutsMap layouts = KeyboardGlobal::getKeyboardLayouts();
+    for ( KeyboardGlobal::LayoutsMap::const_iterator it = layouts.constBegin(); it != layouts.constEnd(); ++it )
     {
-        return a.second.description < b.second.description;
-    } );
+        m_layouts.append( qMakePair( it.key(), it.value() ) );
+    }
+
+    std::stable_sort( m_layouts.begin(),
+                      m_layouts.end(),
+                      []( const QPair< QString, KeyboardGlobal::KeyboardInfo >& a,
+                          const QPair< QString, KeyboardGlobal::KeyboardInfo >& b ) {
+                          return a.second.description < b.second.description;
+                      } );
+}
+
+QHash< int, QByteArray >
+KeyboardLayoutModel::roleNames() const
+{
+    return { { Qt::DisplayRole, "label" }, { KeyboardLayoutKeyRole, "key" }, { KeyboardVariantsRole, "variants" } };
+}
+
+void
+KeyboardLayoutModel::setCurrentIndex( const int& index )
+{
+    if ( index >= m_layouts.count() || index < 0 )
+    {
+        return;
+    }
+
+    m_currentIndex = index;
+    emit currentIndexChanged( m_currentIndex );
+}
+
+int
+KeyboardLayoutModel::currentIndex() const
+{
+    return m_currentIndex;
 }
