@@ -18,7 +18,11 @@
  */
 
 #include "LocaleConfiguration.h"
+
+#include "utils/Logger.h"
+
 #include <QLocale>
+#include <QRegularExpression>
 
 LocaleConfiguration::LocaleConfiguration()
     : explicit_lang( false )
@@ -53,14 +57,9 @@ LocaleConfiguration::fromLanguageAndLocation( const QString& languageLocale,
 {
     QString language = languageLocale.split( '_' ).first();
 
-    QStringList linesForLanguage;
-    for ( const QString& line : availableLocales )
-    {
-        if ( line.startsWith( language ) )
-        {
-            linesForLanguage.append( line );
-        }
-    }
+    // Either an exact match, or the whole language part matches
+    // (followed by .<encoding> or _<country>
+    QStringList linesForLanguage = availableLocales.filter( QRegularExpression( language + "[._]" ) );
 
     QString lang;
     if ( linesForLanguage.length() == 0 || languageLocale.isEmpty() )
@@ -71,23 +70,6 @@ LocaleConfiguration::fromLanguageAndLocation( const QString& languageLocale,
     {
         lang = linesForLanguage.first();
     }
-    else
-    {
-        QStringList linesForLanguageUtf;
-        // FIXME: this might be useless if we already filter out non-UTF8 locales
-        foreach ( QString line, linesForLanguage )
-        {
-            if ( line.contains( "UTF-8", Qt::CaseInsensitive ) || line.contains( "utf8", Qt::CaseInsensitive ) )
-            {
-                linesForLanguageUtf.append( line );
-            }
-        }
-
-        if ( linesForLanguageUtf.length() == 1 )
-        {
-            lang = linesForLanguageUtf.first();
-        }
-    }
 
     // lang could still be empty if we found multiple locales that satisfy myLanguage
 
