@@ -22,11 +22,11 @@
 #include <QObject>
 #include <QVariantMap>
 
-#include <CppJob.h>
+#include "CppJob.h"
 
-#include <utils/PluginFactory.h>
+#include "utils/PluginFactory.h"
 
-#include <DllMacro.h>
+#include "DllMacro.h"
 
 class PLUGINDLLEXPORT MachineIdJob : public Calamares::CppJob
 {
