@@ -21,6 +21,7 @@
 #ifndef NETINSTALLPAGE_H
 #define NETINSTALLPAGE_H
 
+#include "Config.h"
 #include "PackageModel.h"
 #include "PackageTreeItem.h"
 
@@ -42,7 +43,7 @@ class NetInstallPage : public QWidget
 {
     Q_OBJECT
 public:
-    NetInstallPage( QWidget* parent = nullptr );
+    NetInstallPage( Config* config, QWidget* parent = nullptr );
     virtual ~NetInstallPage();
 
     /** @brief Sets the page title
@@ -58,45 +59,22 @@ public:
 
     void onActivate();
 
-    /** @brief Retrieves the groups, with name, description and packages
-     *
-     * Loads data from the given URL. This should be called before
-     * displaying the page.
-     */
-    void loadGroupList( const QString& url );
-
-    // Sets the "required" state of netinstall data. Influences whether
-    // corrupt or unavailable data causes checkReady() to be emitted
-    // true (not-required) or false.
-    void setRequired( bool );
-    bool getRequired() const { return m_required; }
-
-    // Returns the list of packages belonging to groups that are
-    // selected in the view in this given moment. No data is cached here, so
-    // this function does not have constant time.
-    PackageModel::PackageItemDataList selectedPackages() const;
-
 public slots:
-    void dataIsHere();
-
     void retranslate();
+    void setStatus( QString s );
 
-signals:
-    void checkReady( bool );
+    /** @brief Expand entries that should be pre-expanded.
+     *
+     * Follows the *expanded* key / the startExpanded field in the
+     * group entries of the model. Call this after filling up the model.
+     */
+    void expandGroups();
 
 private:
-    // Takes the YAML data representing the groups and reads them into the
-    // m_groups and m_groupOrder internal structures. See the README.md
-    // of this module to know the format expected of the YAML files.
-    bool readGroups( const QByteArray& yamlData );
-
+    Config* m_config;
     Ui::Page_NetInst* ui;
 
     std::unique_ptr< CalamaresUtils::Locale::TranslatedString > m_title;  // Above the treeview
-
-    QNetworkReply* m_reply;
-    PackageModel* m_groups;
-    bool m_required;
 };
 
 #endif  // NETINSTALLPAGE_H
