@@ -144,6 +144,14 @@ PackageChooserViewStep::isAtEnd() const
     return true;
 }
 
+void
+PackageChooserViewStep::onActivate()
+{
+    if ( !m_widget->hasSelection() )
+    {
+        m_widget->setSelection( m_defaultIdx );
+    }
+}
 
 void
 PackageChooserViewStep::onLeave()
@@ -184,8 +192,7 @@ PackageChooserViewStep::setConfigurationMap( const QVariantMap& configurationMap
     if ( m_id.isEmpty() )
     {
         // Not set, so use the instance id
-        // TODO: use a stronger type than QString for structured IDs
-        m_id = moduleInstanceKey().split( '@' ).last();
+        m_id = moduleInstanceKey().id();
     }
 
     bool labels_ok = false;
@@ -198,6 +205,9 @@ PackageChooserViewStep::setConfigurationMap( const QVariantMap& configurationMap
         }
     }
 
+    QString default_item_id = CalamaresUtils::getString( configurationMap, "default" );
+    m_defaultIdx = QModelIndex();
+
     bool first_time = !m_model;
     if ( configurationMap.contains( "items" ) )
     {
@@ -208,6 +218,22 @@ PackageChooserViewStep::setConfigurationMap( const QVariantMap& configurationMap
     {
         hookupModel();
     }
+
+    // find default item
+    if ( first_time && m_model && !default_item_id.isEmpty() )
+    {
+        for ( int item_n = 0; item_n < m_model->packageCount(); ++item_n )
+        {
+            QModelIndex item_idx = m_model->index( item_n, 0 );
+            QVariant item_id = m_model->data( item_idx, PackageListModel::IdRole );
+
+            if ( item_id.toString() == default_item_id )
+            {
+                m_defaultIdx = item_idx;
+                break;
+            }
+        }
+    }
 }
 
 void
