@@ -20,7 +20,10 @@
 #include "core/ColorUtils.h"
 
 #include "core/KPMHelpers.h"
-#include "core/PartitionIterator.h"
+
+#include "partition/PartitionIterator.h"
+#include "partition/PartitionQuery.h"
+#include "utils/Logger.h"
 
 // KPMcore
 #include <kpmcore/core/partition.h>
@@ -30,23 +33,25 @@
 #include <QColor>
 #include <QMap>
 
+using CalamaresUtils::Partition::isPartitionFreeSpace;
+using CalamaresUtils::Partition::isPartitionNew;
+using CalamaresUtils::Partition::PartitionIterator;
+
 static const int NUM_PARTITION_COLORS = 5;
 static const int NUM_NEW_PARTITION_COLORS = 4;
 //Let's try to use the Breeze palette
-static const QColor PARTITION_COLORS[ NUM_PARTITION_COLORS ] =
-{
-    "#2980b9", //Dark Plasma Blue
-    "#27ae60", //Dark Icon Green
-    "#c9ce3b", //Dirty Yellow
-    "#3daee9", //Plasma Blue
-    "#9b59b6", //Purple
+static const QColor PARTITION_COLORS[ NUM_PARTITION_COLORS ] = {
+    "#2980b9",  //Dark Plasma Blue
+    "#27ae60",  //Dark Icon Green
+    "#c9ce3b",  //Dirty Yellow
+    "#3daee9",  //Plasma Blue
+    "#9b59b6",  //Purple
 };
-static const QColor NEW_PARTITION_COLORS[ NUM_NEW_PARTITION_COLORS ] =
-{
-    "#c0392b", //Dark Icon Red
-    "#f39c1f", //Dark Icon Yellow
-    "#f1b7bc", //Light Salmon
-    "#fed999", //Light Orange
+static const QColor NEW_PARTITION_COLORS[ NUM_NEW_PARTITION_COLORS ] = {
+    "#c0392b",  //Dark Icon Red
+    "#f39c1f",  //Dark Icon Yellow
+    "#f1b7bc",  //Light Salmon
+    "#fed999",  //Light Orange
 };
 static QColor FREE_SPACE_COLOR = "#777777";
 static QColor EXTENDED_COLOR = "#aaaaaa";
@@ -58,12 +63,14 @@ static QMap< QString, QColor > s_partitionColorsCache;
 namespace ColorUtils
 {
 
-QColor freeSpaceColor()
+QColor
+freeSpaceColor()
 {
     return FREE_SPACE_COLOR;
 }
 
-QColor unknownDisklabelColor()
+QColor
+unknownDisklabelColor()
 {
     return UNKNOWN_DISKLABEL_COLOR;
 }
@@ -71,9 +78,10 @@ QColor unknownDisklabelColor()
 PartitionNode*
 _findRootForPartition( PartitionNode* partition )
 {
-    if ( partition->isRoot() ||
-         !partition->parent() )
+    if ( partition->isRoot() || !partition->parent() )
+    {
         return partition;
+    }
 
     return _findRootForPartition( partition->parent() );
 }
@@ -81,24 +89,37 @@ _findRootForPartition( PartitionNode* partition )
 QColor
 colorForPartition( Partition* partition )
 {
-    if ( KPMHelpers::isPartitionFreeSpace( partition ) )
+    if ( !partition )
+    {
+        cWarning() << "NULL partition";
         return FREE_SPACE_COLOR;
-    if ( partition->roles().has( PartitionRole::Extended ) )
-        return EXTENDED_COLOR;
+    }
 
-    if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone &&
-         !partition->fileSystem().uuid().isEmpty() )
+    if ( isPartitionFreeSpace( partition ) )
+    {
+        return FREE_SPACE_COLOR;
+    }
+    if ( partition->roles().has( PartitionRole::Extended ) )
+    {
+        return EXTENDED_COLOR;
+    }
+
+    if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
+         && !partition->fileSystem().uuid().isEmpty() )
     {
         if ( partition->fileSystem().type() == FileSystem::Luks )
         {
             FS::luks& luksFs = dynamic_cast< FS::luks& >( partition->fileSystem() );
-            if ( !luksFs.outerUuid().isEmpty() &&
-                 s_partitionColorsCache.contains( luksFs.outerUuid() ) )
+            if ( !luksFs.outerUuid().isEmpty() && s_partitionColorsCache.contains( luksFs.outerUuid() ) )
+            {
                 return s_partitionColorsCache[ luksFs.outerUuid() ];
+            }
         }
 
         if ( s_partitionColorsCache.contains( partition->fileSystem().uuid() ) )
+        {
             return s_partitionColorsCache[ partition->fileSystem().uuid() ];
+        }
     }
 
     // No partition-specific color needed, pick one from our list, but skip
@@ -109,27 +130,30 @@ colorForPartition( Partition* partition )
     Q_ASSERT( table );
     int colorIdx = 0;
     int newColorIdx = 0;
-    for ( PartitionIterator it = PartitionIterator::begin( table );
-          it != PartitionIterator::end( table );
-          ++it )
+    for ( PartitionIterator it = PartitionIterator::begin( table ); it != PartitionIterator::end( table ); ++it )
     {
         Partition* child = *it;
         if ( child == partition )
-            break;
-        if ( !KPMHelpers::isPartitionFreeSpace( child ) &&
-             !child->hasChildren() )
         {
-            if ( KPMHelpers::isPartitionNew( child ) )
+            break;
+        }
+        if ( !isPartitionFreeSpace( child ) && !child->hasChildren() )
+        {
+            if ( isPartitionNew( child ) )
+            {
                 ++newColorIdx;
+            }
             ++colorIdx;
         }
     }
 
-    if ( KPMHelpers::isPartitionNew( partition ) )
+    if ( isPartitionNew( partition ) )
+    {
         return NEW_PARTITION_COLORS[ newColorIdx % NUM_NEW_PARTITION_COLORS ];
+    }
 
-    if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone &&
-         !partition->fileSystem().uuid().isEmpty() )
+    if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
+         && !partition->fileSystem().uuid().isEmpty() )
     {
         if ( partition->fileSystem().type() == FileSystem::Luks )
         {
@@ -155,17 +179,17 @@ colorForPartitionInFreeSpace( Partition* partition )
     PartitionTable* table = dynamic_cast< PartitionTable* >( parent );
     Q_ASSERT( table );
     int newColorIdx = 0;
-    for ( PartitionIterator it = PartitionIterator::begin( table );
-          it != PartitionIterator::end( table );
-          ++it )
+    for ( PartitionIterator it = PartitionIterator::begin( table ); it != PartitionIterator::end( table ); ++it )
     {
         Partition* child = *it;
         if ( child == partition )
+        {
             break;
-        if ( !KPMHelpers::isPartitionFreeSpace( child ) &&
-             !child->hasChildren() &&
-             KPMHelpers::isPartitionNew( child ) )
+        }
+        if ( !isPartitionFreeSpace( child ) && !child->hasChildren() && isPartitionNew( child ) )
+        {
             ++newColorIdx;
+        }
     }
     return NEW_PARTITION_COLORS[ newColorIdx % NUM_NEW_PARTITION_COLORS ];
 }
@@ -177,4 +201,4 @@ invalidateCache()
     s_partitionColorsCache.clear();
 }
 
-} // namespace
+}  // namespace ColorUtils
