@@ -31,6 +31,7 @@
 // Qt
 #include <QList>
 #include <QObject>
+#include <QVariantMap>
 
 class Partition;
 
@@ -40,8 +41,10 @@ public:
     struct PartitionEntry
     {
         QString partLabel;
+        QString partType;
         QString partMountPoint;
         FileSystem::Type partFileSystem = FileSystem::Unknown;
+        QVariantMap partFeatures;
         CalamaresUtils::Partition::PartitionSize partSize;
         CalamaresUtils::Partition::PartitionSize partMinSize;
         CalamaresUtils::Partition::PartitionSize partMaxSize;
@@ -73,8 +76,10 @@ public:
                    const QString& min = QString(),
                    const QString& max = QString() );
     bool addEntry( const QString& label,
+                   const QString& type,
                    const QString& mountPoint,
                    const QString& fs,
+                   const QVariantMap& features,
                    const QString& size,
                    const QString& min = QString(),
                    const QString& max = QString() );
