@@ -61,6 +61,7 @@ public:
 
         ResetHelper( const ResetHelper& ) = delete;
         ResetHelper& operator=( const ResetHelper& ) = delete;
+
     private:
         PartitionModel* m_model;
     };
@@ -75,7 +76,7 @@ public:
         FileSystemLabelRole,
         FileSystemTypeRole,
         PartitionPathRole,
-        PartitionPtrRole,   // passed as void*, use sparingly
+        PartitionPtrRole,  // passed as void*, use sparingly
         OsproberNameRole,
         OsproberPathRole,
         OsproberCanBeResizedRole,
@@ -89,7 +90,7 @@ public:
         FileSystemColumn,
         MountPointColumn,
         SizeColumn,
-        ColumnCount // Must remain last
+        ColumnCount  // Must remain last
     };
 
     PartitionModel( QObject* parent = nullptr );
@@ -108,10 +109,7 @@ public:
 
     Partition* partitionForIndex( const QModelIndex& index ) const;
 
-    Device* device() const
-    {
-        return m_device;
-    }
+    Device* device() const { return m_device; }
 
     void update();
 
