@@ -133,13 +133,14 @@ ReplaceWidget::onPartitionSelected()
     if ( Calamares::JobQueue::instance()->globalStorage()->value( "firmwareType" ) == "efi" )
         m_isEfi = true;
 
+    const auto* branding = Calamares::Branding::instance();
     if ( m_ui->partitionTreeView->currentIndex() == QModelIndex() )
     {
         updateStatus( CalamaresUtils::PartitionPartition,
                       tr( "Select where to install %1.<br/>"
                           "<font color=\"red\">Warning: </font>this will delete all files "
                           "on the selected partition." )
-                          .arg( *Calamares::Branding::VersionedName ) );
+                          .arg( branding->versionedName() ) );
         setNextEnabled( false );
         return;
     }
@@ -172,7 +173,7 @@ ReplaceWidget::onPartitionSelected()
             updateStatus( CalamaresUtils::Fail,
                           tr( "%1 cannot be installed on empty space. Please select an "
                               "existing partition." )
-                          .arg( *Calamares::Branding::VersionedName ) );
+                          .arg( branding->versionedName() ) );
             setNextEnabled( false );
             return;
         }
@@ -182,7 +183,7 @@ ReplaceWidget::onPartitionSelected()
             updateStatus( CalamaresUtils::Fail,
                           tr( "%1 cannot be installed on an extended partition. Please select an "
                               "existing primary or logical partition." )
-                          .arg( *Calamares::Branding::VersionedName ) );
+                          .arg( branding->versionedName() ) );
             setNextEnabled( false );
             return;
         }
@@ -191,7 +192,7 @@ ReplaceWidget::onPartitionSelected()
         {
             updateStatus( CalamaresUtils::Fail,
                           tr( "%1 cannot be installed on this partition." )
-                          .arg( *Calamares::Branding::VersionedName ) );
+                          .arg( branding->versionedName() ) );
             setNextEnabled( false );
             return;
         }
@@ -233,7 +234,7 @@ ReplaceWidget::onPartitionSelected()
                               "The partition %1 is too small for %2. Please select a partition "
                               "with capacity at least %3 GiB." )
                           .arg( partition->partitionPath() )
-                          .arg( *Calamares::Branding::VersionedName )
+                          .arg( branding->versionedName() )
                           .arg( requiredSpaceB / ( 1024. * 1024. * 1024. ),
                                 0, 'f', 1 )
                           .arg( prettyName ) );
@@ -256,7 +257,7 @@ ReplaceWidget::onPartitionSelected()
                                   "An EFI system partition cannot be found anywhere "
                                   "on this system. Please go back and use manual "
                                   "partitioning to set up %1." )
-                              .arg( *Calamares::Branding::ShortProductName )
+                              .arg( branding->shortProductName() )
                               .arg( prettyName ) );
                 setNextEnabled( false );
             }
@@ -267,14 +268,14 @@ ReplaceWidget::onPartitionSelected()
                                   "%1 will be installed on %2.<br/>"
                                   "<font color=\"red\">Warning: </font>all data on partition "
                                   "%2 will be lost.")
-                                .arg( *Calamares::Branding::VersionedName )
+                                .arg( branding->versionedName() )
                                 .arg( partition->partitionPath() )
                                 .arg( prettyName ) );
                 m_ui->bootStatusLabel->show();
                 m_ui->bootStatusLabel->setText(
                     tr( "The EFI system partition at %1 will be used for starting %2." )
                         .arg( efiSystemPartitions.first()->partitionPath() )
-                        .arg( *Calamares::Branding::ShortProductName ) );
+                        .arg( branding->shortProductName() ) );
                 setNextEnabled( true );
             }
             else
@@ -284,7 +285,7 @@ ReplaceWidget::onPartitionSelected()
                                   "%1 will be installed on %2.<br/>"
                                   "<font color=\"red\">Warning: </font>all data on partition "
                                   "%2 will be lost.")
-                                .arg( *Calamares::Branding::VersionedName )
+                                .arg( branding->versionedName() )
                                 .arg( partition->partitionPath() )
                                 .arg( prettyName ) );
                 m_ui->bootStatusLabel->show();
@@ -308,7 +309,7 @@ ReplaceWidget::onPartitionSelected()
                               "%1 will be installed on %2.<br/>"
                               "<font color=\"red\">Warning: </font>all data on partition "
                               "%2 will be lost.")
-                            .arg( *Calamares::Branding::VersionedName )
+                            .arg( branding->versionedName() )
                             .arg( partition->partitionPath() )
                             .arg( prettyName ) );
             setNextEnabled( true );
