@@ -18,7 +18,7 @@
  *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "jobs/CreatePartitionTableJob.h"
+#include "CreatePartitionTableJob.h"
 
 #include "partition/PartitionIterator.h"
 #include "utils/Logger.h"
@@ -46,16 +46,17 @@ QString
 CreatePartitionTableJob::prettyName() const
 {
     return tr( "Create new %1 partition table on %2." )
-            .arg( PartitionTable::tableTypeToName( m_type ) )
-            .arg( m_device->deviceNode() );
+        .arg( PartitionTable::tableTypeToName( m_type ) )
+        .arg( m_device->deviceNode() );
 }
 
-QString CreatePartitionTableJob::prettyDescription() const
+QString
+CreatePartitionTableJob::prettyDescription() const
 {
     return tr( "Create new <strong>%1</strong> partition table on <strong>%2</strong> (%3)." )
-            .arg( PartitionTable::tableTypeToName( m_type ).toUpper() )
-            .arg( m_device->deviceNode() )
-            .arg( m_device->name() );
+        .arg( PartitionTable::tableTypeToName( m_type ).toUpper() )
+        .arg( m_device->deviceNode() )
+        .arg( m_device->name() );
 }
 
 
@@ -63,13 +64,13 @@ QString
 CreatePartitionTableJob::prettyStatusMessage() const
 {
     return tr( "Creating new %1 partition table on %2." )
-            .arg( PartitionTable::tableTypeToName( m_type ).toUpper() )
-            .arg( m_device->deviceNode() );
+        .arg( PartitionTable::tableTypeToName( m_type ).toUpper() )
+        .arg( m_device->deviceNode() );
 }
 
 
 static inline QDebug&
-operator <<( QDebug& s, PartitionIterator& it )
+operator<<( QDebug&& s, PartitionIterator& it )
 {
     s << ( ( *it ) ? ( *it )->deviceNode() : QString( "<null device>" ) );
     return s;
@@ -83,14 +84,14 @@ CreatePartitionTableJob::exec()
     QString message = tr( "The installer failed to create a partition table on %1." ).arg( m_device->name() );
 
     PartitionTable* table = m_device->partitionTable();
-    cDebug() << "Creating new partition table of type" << table->typeName()
-             << ", uncommitted yet:";
+    cDebug() << "Creating new partition table of type" << table->typeName() << ", uncommitted yet:";
 
     if ( Logger::logLevelEnabled( Logger::LOGDEBUG ) )
     {
-        for ( auto it = PartitionIterator::begin( table );
-            it != PartitionIterator::end( table ); ++it )
+        for ( auto it = PartitionIterator::begin( table ); it != PartitionIterator::end( table ); ++it )
+        {
             cDebug() << it;
+        }
 
         QProcess lsblk;
         lsblk.setProgram( "lsblk" );
@@ -107,13 +108,15 @@ CreatePartitionTableJob::exec()
         cDebug() << "mount:\n" << mount.readAllStandardOutput();
     }
 
-    CreatePartitionTableOperation op(*m_device, table);
-    op.setStatus(Operation::StatusRunning);
+    CreatePartitionTableOperation op( *m_device, table );
+    op.setStatus( Operation::StatusRunning );
 
-    if (op.execute(report))
+    if ( op.execute( report ) )
+    {
         return Calamares::JobResult::ok();
+    }
 
-    return Calamares::JobResult::error(message, report.toText());
+    return Calamares::JobResult::error( message, report.toText() );
 }
 
 void
@@ -129,10 +132,8 @@ CreatePartitionTableJob::updatePreview()
 PartitionTable*
 CreatePartitionTableJob::createTable()
 {
-    cDebug() << "CreatePartitionTableJob::createTable trying to make table for device"
-             << m_device->deviceNode();
+    cDebug() << "CreatePartitionTableJob::createTable trying to make table for device" << m_device->deviceNode();
     return new PartitionTable( m_type,
                                PartitionTable::defaultFirstUsable( *m_device, m_type ),
-                               PartitionTable::defaultLastUsable( *m_device, m_type )
-                             );
+                               PartitionTable::defaultLastUsable( *m_device, m_type ) );
 }
