@@ -43,10 +43,10 @@ QString
 FormatPartitionJob::prettyName() const
 {
     return tr( "Format partition %1 (file system: %2, size: %3 MiB) on %4." )
-           .arg( m_partition->partitionPath() )
-           .arg( userVisibleFS( m_partition->fileSystem() ) )
-           .arg( m_partition->capacity() / 1024 / 1024 )
-            .arg( m_device->name() );
+        .arg( m_partition->partitionPath() )
+        .arg( userVisibleFS( m_partition->fileSystem() ) )
+        .arg( m_partition->capacity() / 1024 / 1024 )
+        .arg( m_device->name() );
 }
 
 
@@ -55,9 +55,9 @@ FormatPartitionJob::prettyDescription() const
 {
     return tr( "Format <strong>%3MiB</strong> partition <strong>%1</strong> with "
                "file system <strong>%2</strong>." )
-           .arg( m_partition->partitionPath() )
-           .arg( userVisibleFS( m_partition->fileSystem() ) )
-            .arg( m_partition->capacity() / 1024 / 1024 );
+        .arg( m_partition->partitionPath() )
+        .arg( userVisibleFS( m_partition->fileSystem() ) )
+        .arg( m_partition->capacity() / 1024 / 1024 );
 }
 
 
@@ -66,8 +66,8 @@ FormatPartitionJob::prettyStatusMessage() const
 {
     return tr( "Formatting partition %1 with "
                "file system %2." )
-           .arg( m_partition->partitionPath() )
-           .arg( userVisibleFS( m_partition->fileSystem() ) );
+        .arg( m_partition->partitionPath() )
+        .arg( userVisibleFS( m_partition->fileSystem() ) );
 }
 
 
@@ -75,13 +75,16 @@ Calamares::JobResult
 FormatPartitionJob::exec()
 {
     Report report( nullptr );  // Root of the report tree, no parent
-    CreateFileSystemOperation op(*m_device, *m_partition, m_partition->fileSystem().type());
-    op.setStatus(Operation::StatusRunning);
+    CreateFileSystemOperation op( *m_device, *m_partition, m_partition->fileSystem().type() );
+    op.setStatus( Operation::StatusRunning );
 
-    QString message = tr( "The installer failed to format partition %1 on disk '%2'." ).arg( m_partition->partitionPath(), m_device->name() );
+    QString message = tr( "The installer failed to format partition %1 on disk '%2'." )
+                          .arg( m_partition->partitionPath(), m_device->name() );
 
-    if (op.execute(report))
+    if ( op.execute( report ) )
+    {
         return Calamares::JobResult::ok();
+    }
 
-    return Calamares::JobResult::error(message, report.toText());
+    return Calamares::JobResult::error( message, report.toText() );
 }
